Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(18)

Unified Diff: ash/common/system/tray/tray_background_view.h

Issue 2477463003: Replace ui::AXViewState with AXNodeData and AXActionData (Closed)
Patch Set: Full patch including mechanical changes Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/system/tray/tray_background_view.h
diff --git a/ash/common/system/tray/tray_background_view.h b/ash/common/system/tray/tray_background_view.h
index cb22ed649c3838b98a402bd197f156133da76f4f..b642ca692d688ae12e4acb071bea3796d18a2891 100644
--- a/ash/common/system/tray/tray_background_view.h
+++ b/ash/common/system/tray/tray_background_view.h
@@ -73,7 +73,7 @@ class ASH_EXPORT TrayBackgroundView : public ActionableView,
void SetVisible(bool visible) override;
const char* GetClassName() const override;
void ChildPreferredSizeChanged(views::View* child) override;
- void GetAccessibleState(ui::AXViewState* state) override;
+ void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
void AboutToRequestFocusFromTabTraversal(bool reverse) override;
void OnPaint(gfx::Canvas* canvas) override;
@@ -88,7 +88,7 @@ class ASH_EXPORT TrayBackgroundView : public ActionableView,
// Called when the anchor (tray or bubble) may have moved or changed.
virtual void AnchorUpdated() {}
// Called from GetAccessibleState, must return a valid accessible name.
virtual base::string16 GetAccessibleNameForTray() = 0;
// Called when the bubble is resized.
@@ -88,7 +88,7 @@ class ASH_EXPORT TrayBackgroundView : public ActionableView,
// Called when the anchor (tray or bubble) may have moved or changed.
virtual void AnchorUpdated() {}
- // Called from GetAccessibleState, must return a valid accessible name.
+ // Called from GetAccessibleNodeData, must return a valid accessible name.
virtual base::string16 GetAccessibleNameForTray() = 0;
// Called when the bubble is resized.

Powered by Google App Engine
This is Rietveld 408576698